// ====================================================================================================
// An example loading a library script from the file, and using it.
//   See: https://www.vcssl.org/en-us/vnano/doc/tutorial/feature
// 
// ファイルからライブラリスクリプトを読み込み、使用するサンプルコードです。
//   参照: https://www.vcssl.org/ja-jp/vnano/doc/tutorial/feature
// 
// License: CC0 (Copyright Free)
// ====================================================================================================

import org.vcssl.nano.VnanoEngine;
import org.vcssl.nano.VnanoException;
import org.vcssl.nano.interconnect.ScriptLoader;

public class ExampleApp6 {
    public static void main(String[] args) throws VnanoException {

        // Create a scripting engine of Vnano (= Vnano Engine).
        // Vnano Engine のインスタンスを生成
        VnanoEngine engine = new VnanoEngine();

        // Load library scripts from files.
        // ライブラ リスクリプトをファイルから読み込む
        ScriptLoader scriptLoader = new ScriptLoader("UTF-8");
        scriptLoader.setLibraryScriptListPath("./lib/VnanoLibraryList.txt");
        scriptLoader.load();

        // Register library scripts to Vnano Engine.
        // 読み込んだライブラリ スクリプトを VnanoEngine に登録
        String[] libPaths = scriptLoader.getLibraryScriptPaths(true);
        String[] libScripts = scriptLoader.getLibraryScriptContents();
        int libCount = libScripts.length;
            for (int ilib=0; ilib<libCount; ilib++) {
            engine.registerLibraryScript(libPaths[ilib], libScripts[ilib]);
        }

        // Prepare the content of the script to be executed.
        // 実行するスクリプトの内容を用意
        String script =

            " float value = 1.2 + f(x); " +
            " value;                      " ;

        // Execute a scriptby Vnano Engine.
        // Vnano Engine でスクリプトを実行
        double result = (Double)engine.executeScript(script);
        System.out.println("result: " + result);
    }
}
